@@ -411,6 +411,43 @@ class TaskMonkClient:
         logging.debug('file_url = %s', file_url)
         urlretrieve(file_url, local_path)
         return local_path
+
+    def get_batch_and_user_output(self, batch_id, local_path, output_format = 'CSV', fields = [], completed_only = False):
+        """
+        Parameters
+        ----------
+        batch_id: str
+             Id for the batch
+
+        local_path: str
+            Path of the file where the ouput should be stored
+
+        output_format: str
+            Format of the output. Should be 'CSV' or 'Excel'
+        
+        fields: Array of String
+            The fields that should be included in the output file. 
+            The names should match the project configuration and the headers in the input file that was used for the task upload. 
+            Pass an empty string to retrieve all fields
+
+        completed_only: boolean
+            Set this flag to True to download only completed tasks in a batch. Default value for this parameter is False
+
+        Returns
+        -------
+        str
+            local_path where the output is saved
+
+        """
+        url = self._base_url + urlConfig.URLS['Project'] + self._project_id + '/batch/' + batch_id + '/output/file?output_format=' + output_format
+        data = json.dumps({'field_names': fields, 'completedOnly': completed_only})
+        response = apiCall.post(self.__get_token(), url,self._proxy, data, 30)
+        file_url = response['file_url']
+        job_id = response['job_id']
+        self._wait_for_job_completion(job_id)
+        logging.debug('file_url = %s', file_url)
+        urlretrieve(file_url, local_path)
+        return local_path
     
     def _get_batch(self):
         """ Retrieves batches for the project"""
